import {styled} from "@mui/material";

export const ImageObjectContainer = styled('div')`
    width: 180px;
    height: 180px;
    margin: 8px;
`;

export const Image = styled('img')`
    object-fit: contain;
    width: 100%;
    height: 100%;
`;